@@ -22,9 +22,7 @@
 #' @export
 #' @rdname add_files
 #' @importFrom attempt stop_if
-#' @importFrom cli cat_bullet
 #' @importFrom utils file.edit
-#' @importFrom fs path_abs path file_create file_exists
 #'
 #' @note `add_ui_server_files` will be deprecated in future version of `{golem}`
 #'
@@ -43,12 +41,14 @@ add_js_file <- function(
 ) {
   stop_if(
     missing(name),
-    msg = "Name is required"
+    msg = "`name` is required"
   )
 
+  check_name_length(name)
+
   name <- file_path_sans_ext(name)
 
-  old <- setwd(path_abs(pkg))
+  old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
   dir_created <- create_if_needed(
@@ -61,16 +61,15 @@ add_js_file <- function(
     return(invisible(FALSE))
   }
 
-  dir <- path_abs(dir)
+  dir <- fs_path_abs(dir)
 
-  where <- path(
+  where <- fs_path(
     dir,
     sprintf("%s.js", name)
   )
 
-  if (!file.exists(where)) {
-    file_create(where)
-
+  if (!fs_file_exists(where)) {
+    fs_file_create(where)
     if (with_doc_ready) {
       write_there <- function(...) {
         write(..., file = where, append = TRUE)
@@ -99,8 +98,6 @@ add_js_file <- function(
 
 #' @export
 #' @rdname add_files
-#'
-#' @importFrom fs path_abs path file_create file_exists
 add_js_handler <- function(
   name,
   pkg = get_golem_wd(),
@@ -112,12 +109,14 @@ add_js_handler <- function(
 ) {
   attempt::stop_if(
     missing(name),
-    msg = "Name is required"
+    msg = "`name` is required"
   )
 
+  check_name_length(name)
+
   name <- file_path_sans_ext(name)
 
-  old <- setwd(path_abs(pkg))
+  old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
   dir_created <- create_if_needed(
@@ -130,15 +129,15 @@ add_js_handler <- function(
     return(invisible(FALSE))
   }
 
-  dir <- path_abs(dir)
+  dir <- fs_path_abs(dir)
 
-  where <- file.path(
+  where <- fs_path(
     dir,
     sprintf("%s.js", name)
   )
 
-  if (!file.exists(where)) {
-    file_create(where)
+  if (!fs_file_exists(where)) {
+    fs_file_create(where)
 
     template(path = where, ...)
 
@@ -160,7 +159,6 @@ add_js_handler <- function(
 
 #' @export
 #' @rdname add_files
-#' @importFrom fs path_abs path file_create file_exists
 add_js_input_binding <- function(
   name,
   pkg = get_golem_wd(),
@@ -176,9 +174,11 @@ add_js_input_binding <- function(
 ) {
   attempt::stop_if(
     missing(name),
-    msg = "Name is required"
+    msg = "`name` is required"
   )
 
+  check_name_length(name)
+
   attempt::stop_if(
     length(events$name) == 0,
     msg = "At least one event is required"
@@ -195,7 +195,7 @@ add_js_input_binding <- function(
     sprintf("input-%s", name)
   )
 
-  old <- setwd(path_abs(pkg))
+  old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
   dir_created <- create_if_needed(
@@ -208,15 +208,15 @@ add_js_input_binding <- function(
     return(invisible(FALSE))
   }
 
-  dir <- path_abs(dir)
+  dir <- fs_path_abs(dir)
 
-  where <- file.path(
+  where <- fs_path(
     dir,
     sprintf("%s.js", name)
   )
 
-  if (!file.exists(where)) {
-    file_create(where)
+  if (!fs_file_exists(where)) {
+    fs_file_create(where)
 
     write_there <- function(...) {
       write(..., file = where, append = TRUE)
@@ -307,7 +307,6 @@ add_js_input_binding <- function(
 
 #' @export
 #' @rdname add_files
-#' @importFrom fs path_abs path file_create file_exists
 add_js_output_binding <- function(
   name,
   pkg = get_golem_wd(),
@@ -317,16 +316,18 @@ add_js_output_binding <- function(
 ) {
   attempt::stop_if(
     missing(name),
-    msg = "Name is required"
+    msg = "`name` is required"
   )
 
+  check_name_length(name)
+
   raw_name <- name
 
   name <- file_path_sans_ext(
     sprintf("output-%s", name)
   )
 
-  old <- setwd(path_abs(pkg))
+  old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
   dir_created <- create_if_needed(
@@ -339,15 +340,15 @@ add_js_output_binding <- function(
     return(invisible(FALSE))
   }
 
-  dir <- path_abs(dir)
+  dir <- fs_path_abs(dir)
 
-  where <- file.path(
+  where <- fs_path(
     dir,
     sprintf("%s.js", name)
   )
 
-  if (!file.exists(where)) {
-    file_create(where)
+  if (!fs_file_exists(where)) {
+    fs_file_create(where)
 
     write_there <- function(...) {
       write(..., file = where, append = TRUE)
@@ -388,7 +389,6 @@ add_js_output_binding <- function(
 
 #' @export
 #' @rdname add_files
-#' @importFrom fs path_abs path file_create file_exists
 add_css_file <- function(
   name,
   pkg = get_golem_wd(),
@@ -400,12 +400,14 @@ add_css_file <- function(
 ) {
   attempt::stop_if(
     missing(name),
-    msg = "Name is required"
+    msg = "`name` is required"
   )
 
+  check_name_length(name)
+
   name <- file_path_sans_ext(name)
 
-  old <- setwd(path_abs(pkg))
+  old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
   dir_created <- create_if_needed(
@@ -418,9 +420,9 @@ add_css_file <- function(
     return(invisible(FALSE))
   }
 
-  dir <- path_abs(dir)
+  dir <- fs_path_abs(dir)
 
-  where <- path(
+  where <- fs_path(
     dir,
     sprintf(
       "%s.css",
@@ -428,8 +430,8 @@ add_css_file <- function(
     )
   )
 
-  if (!file_exists(where)) {
-    file_create(where)
+  if (!fs_file_exists(where)) {
+    fs_file_create(where)
     template(path = where, ...)
     file_created_dance(
       where,
@@ -449,8 +451,6 @@ add_css_file <- function(
 
 #' @export
 #' @rdname add_files
-#' @importFrom fs path_abs path file_create file_exists
-#' @importFrom cli cli_alert_info
 add_sass_file <- function(
   name,
   pkg = get_golem_wd(),
@@ -462,12 +462,14 @@ add_sass_file <- function(
 ) {
   attempt::stop_if(
     missing(name),
-    msg = "Name is required"
+    msg = "`name` is required"
   )
 
+  check_name_length(name)
+
   name <- file_path_sans_ext(name)
 
-  old <- setwd(path_abs(pkg))
+  old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
   dir_created <- create_if_needed(
@@ -480,9 +482,9 @@ add_sass_file <- function(
     return(invisible(FALSE))
   }
 
-  dir_abs <- path_abs(dir)
+  dir_abs <- fs_path_abs(dir)
 
-  where <- path(
+  where <- fs_path(
     dir_abs,
     sprintf(
       "%s.sass",
@@ -490,8 +492,8 @@ add_sass_file <- function(
     )
   )
 
-  if (!file_exists(where)) {
-    file_create(where)
+  if (!fs_file_exists(where)) {
+    fs_file_create(where)
     template(path = where, ...)
     file_created_dance(
       where,
@@ -502,9 +504,13 @@ add_sass_file <- function(
       open
     )
 
-    add_sass_code(where = where, dir = dir, name = name)
+    add_sass_code(
+      where = where,
+      dir = dir,
+      name = name
+    )
 
-    cli_alert_info(
+    cat_green_tick(
       "After running the compilation, your CSS file will be automatically link in `golem_add_external_resources()`."
     )
   } else {
@@ -517,7 +523,6 @@ add_sass_file <- function(
 
 #' @export
 #' @rdname add_files
-#' @importFrom fs path_abs path file_create file_exists
 add_html_template <- function(
   name = "template.html",
   pkg = get_golem_wd(),
@@ -527,7 +532,9 @@ add_html_template <- function(
 ) {
   name <- file_path_sans_ext(name)
 
-  old <- setwd(path_abs(pkg))
+  check_name_length(name)
+
+  old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
   dir_created <- create_if_needed(
@@ -540,9 +547,9 @@ add_html_template <- function(
     return(invisible(FALSE))
   }
 
-  dir <- path_abs(dir)
+  dir <- fs_path_abs(dir)
 
-  where <- path(
+  where <- fs_path(
     dir,
     sprintf(
       "%s.html",
@@ -550,8 +557,8 @@ add_html_template <- function(
     )
   )
 
-  if (!file_exists(where)) {
-    file_create(where)
+  if (!fs_file_exists(where)) {
+    fs_file_create(where)
     write_there <- function(...) write(..., file = where, append = TRUE)
     write_there("<!DOCTYPE html>")
     write_there("<html>")
@@ -584,18 +591,19 @@ add_html_template <- function(
   }
 }
 
-
 #' @export
 #' @rdname add_files
-#' @importFrom fs path_abs file_create
-add_ui_server_files <- function(
+add_partial_html_template <- function(
+  name = "partial_template.html",
   pkg = get_golem_wd(),
-  dir = "inst/app",
+  dir = "inst/app/www",
+  open = TRUE,
   dir_create = TRUE
 ) {
-  .Deprecated(msg = "This function will be deprecated in a future version of {golem}.\nPlease comment on https://github.com/ThinkR-open/golem/issues/445 if you want it to stay.")
+  name <- file_path_sans_ext(name)
+  check_name_length(name)
 
-  old <- setwd(path_abs(pkg))
+  old <- setwd(fs_path_abs(pkg))
   on.exit(setwd(old))
 
   dir_created <- create_if_needed(
@@ -608,13 +616,68 @@ add_ui_server_files <- function(
     return(invisible(FALSE))
   }
 
-  dir <- path_abs(dir)
+  dir <- fs_path_abs(dir)
+
+  where <- fs_path(
+    dir,
+    sprintf(
+      "%s.html",
+      name
+    )
+  )
+
+  if (!fs_file_exists(where)) {
+    fs_file_create(where)
+    write_there <- function(...) write(..., file = where, append = TRUE)
+    write_there("<div>")
+    write_there("  {{ content }}")
+    write_there("</div>")
+    write_there("")
+    file_created_dance(
+      where,
+      after_creation_message_html_template,
+      pkg,
+      dir,
+      name,
+      open
+    )
+  } else {
+    file_already_there_dance(
+      where = where,
+      open_file = open
+    )
+  }
+}
+
+#' @export
+#' @rdname add_files
+add_ui_server_files <- function(
+  pkg = get_golem_wd(),
+  dir = "inst/app",
+  dir_create = TRUE
+) {
+  .Deprecated(msg = "This function will be deprecated in a future version of {golem}.\nPlease comment on https://github.com/ThinkR-open/golem/issues/445 if you want it to stay.")
+
+  old <- setwd(fs_path_abs(pkg))
+  on.exit(setwd(old))
+
+  dir_created <- create_if_needed(
+    dir,
+    type = "directory"
+  )
+
+  if (!dir_created) {
+    cat_dir_necessary()
+    return(invisible(FALSE))
+  }
+
+  dir <- fs_path_abs(dir)
 
   # UI
-  where <- path(dir, "ui.R")
+  where <- fs_path(dir, "ui.R")
 
-  if (!file_exists(where)) {
-    file_create(where)
+  if (!fs_file_exists(where)) {
+    fs_file_create(where)
 
     write_there <- function(...) write(..., file = where, append = TRUE)
 
@@ -635,9 +698,8 @@ add_ui_server_files <- function(
     "server.R"
   )
 
-
-  if (!file_exists(where)) {
-    file_create(where)
+  if (!fs_file_exists(where)) {
+    fs_file_create(where)
 
     write_there <- function(...) write(..., file = where, append = TRUE)
 
