@@ -1,8 +1,4 @@
 #' @importFrom utils capture.output
-#' @importFrom cli cat_bullet
-#' @importFrom usethis use_build_ignore use_package
-#' @importFrom pkgload pkg_name
-#' @importFrom fs path file_create path_file
 add_rstudio_files <- function(
   pkg,
   open,
@@ -13,21 +9,26 @@ add_rstudio_files <- function(
   )
 ) {
   service <- match.arg(service)
-  where <- path(pkg, "app.R")
+  where <- fs_path(pkg, "app.R")
+
+  rlang::check_installed(
+    "pkgload",
+    reason = "to deploy on RStudio products."
+  )
 
   disable_autoload(
     pkg = pkg
   )
 
-  if (!file_exists(where)) {
-    file_create(where)
+  if (!fs_file_exists(where)) {
+    fs_file_create(where)
 
     write_there <- function(..., here = where) {
       write(..., here, append = TRUE)
     }
 
-    use_build_ignore(path_file(where))
-    use_build_ignore("rsconnect")
+    usethis_use_build_ignore(basename(where))
+    usethis_use_build_ignore("rsconnect")
     write_there("# Launch the ShinyApp (Do not remove this comment)")
     write_there("# To deploy, run: rsconnect::deployApp()")
     write_there("# Or use the blue button on top of this file")
@@ -41,10 +42,12 @@ add_rstudio_files <- function(
       )
     )
 
-    x <- capture.output(use_package("pkgload"))
+    # We add {pkgload} as a dep because it's required to deploy on Connect & stuff
+    usethis_use_package("pkgload")
+
     cat_created(where)
-    cat_line("To deploy, run:")
-    cat_bullet(darkgrey("rsconnect::deployApp()\n"))
+    cli_cat_line("To deploy, run:")
+    cli_cat_bullet(crayon_darkgrey("rsconnect::deployApp()\n"))
     cat_red_bullet(
       sprintf(
         "Note that you'll need to upload the whole package to %s",
