@@ -1,5 +1,42 @@
+# To test locally, run this in a docker container:
+# docker run -d --rm -v $(pwd):/home/golem rocker/shiny:latest tail -f /dev/null
+# Attach VSCode to the container
+# Then run this script in the terminal
 
+# This script is launched internally by ThinkR every day by our GitLab CI
+temp_app <- commandArgs(TRUE)[1]
+if (is.na(temp_app)) {
+  temp_app <- "/golemmetrics"
+}
+cli::cat_bullet(temp_app)
+if (dir.exists(temp_app)) {
+  unlink(temp_app, TRUE, TRUE)
+}
+
+options("repos" = "https://packagemanager.posit.co/cran/__linux__/jammy/latest")
+
+install.packages(c("pak"))
+
+if (!rlang::is_installed("cli")) {
+  pak::pak("cli")
+}
+
+if (!rlang::is_installed("testthat")) {
+  pak::pak("testthat")
+}
+
+if (!rlang::is_installed("desc")) {
+  pak::pak("desc")
+}
+
+if (!rlang::is_installed("devtools")) {
+  pak::pak("devtools")
+}
+
+library(desc)
+library(testthat)
 cat("\n")
+
 # rstudioapi::jobRunScript(here::here("inst/mantests/build.R"), workingDir = here::here())
 cat_ok <- function() cli::cat_bullet("Passed", bullet = "tick", bullet_col = "green")
 
@@ -16,123 +53,63 @@ fakename <- sprintf(
   gsub("[ :-]", "", Sys.time())
 )
 
-# Just so that I can use this script locally too,
-# I set a temporary lib
-#
-cli::cat_rule("Set up for lib")
-
-if (Sys.getenv("CI", "local") == "local") {
-  # If I'm on the CI, we don't change the lib
-  temp_app <- file.path(getwd(), "inst", "golemmetrics")
-  temp_lib <- .libPaths()
-} else {
-  temp_app <- file.path(getwd(), "inst", "golemmetrics")
-  temp_lib <- file.path(tempdir(), "temp_lib")
-  .libPaths(c(temp_lib, .libPaths()))
-}
-
-cli::cat_bullet(temp_app)
-# This will be our golem app
-
-
-if (dir.exists(temp_app)) {
-  unlink(temp_app, TRUE, TRUE)
-}
-
-dir.create(temp_lib, recursive = TRUE)
-
-install.packages(
-  c("remotes", "desc", "testthat", "cli", "fs", "cranlogs"),
-  lib = temp_lib,
-  repo = "https://cran.rstudio.com/"
-)
-
-cli::cat_rule("Install golem")
-
-library(remotes, lib.loc = temp_lib)
-library(desc, lib.loc = temp_lib)
-library(testthat, lib.loc = temp_lib)
-library(cli, lib.loc = temp_lib)
-library(fs, lib.loc = temp_lib)
-
-# We'll need to install golem from the current branch because
-# otherwise the dependency tree breaks
-# install_github(
-#   "ThinkR-open/golem",
-#   ref = Sys.getenv("GITHUB_BASE_REF", "dev"),
-#   force = TRUE,
-#   lib.loc = temp_lib
-# )
-
-# Installing the current version of golem
-install_local(
-  lib.loc = temp_lib
-)
+cli::cat_rule("Installing the dev version of golem")
+pak::pak("thinkr-open/golem@dev")
 
 cli::cat_rule("Install crystalmountains")
-
-tmp_cm <- tempfile(fileext = ".zip")
-download.file(
-  "https://github.com/ThinkR-open/crystalmountains/archive/refs/heads/main.zip",
-  "main.zip"
+pak::pak(
+  "thinkr-open/crystalmountains"
 )
-unzip(tmp_cm)
 
-remotes::install_local(
-  "crystalmountains-main",
-  lib.loc = temp_lib,
-  update = "never"
-)
-unlink("crystalmountains-main")
+cli::cat_rule("Creating a golem based app")
 
 # Going to the temp dir and create a new golem
 cli::cat_rule("Creating a golem based app")
-
-setwd(tempdir())
-
 library(golem)
 
+zz <- file("all.Rout", open = "wt")
+sink(zz)
+sink(zz, type = "message")
+
+# This is our temp app
+
 create_golem(
   temp_app,
   open = FALSE,
   project_hook = crystalmountains::golem_hook
 )
+sink(type = "message")
+sink()
 
 expect_true(
   dir.exists(temp_app)
 )
 
-old <- setwd(temp_app)
+expect_true(
+  any(grepl(
+    "golem::install_dev_deps()",
+    readLines("all.Rout")
+  ))
+)
+unlink("all.Rout", TRUE, TRUE)
 
-here::set_here(temp_app)
+golem::install_dev_deps(force = TRUE)
 
-usethis::use_build_ignore(".here")
-
-if (Sys.getenv("GITHUB_BASE_REF") == "") {
-  usethis::use_dev_package(
-    "golem",
-    remote = "github::ThinkR-open/golem@dev"
-  )
-} else {
-  usethis::use_dev_package(
-    "golem",
-    remote = sprintf(
-      "github::ThinkR-open/golem@dev",
-      Sys.getenv("GITHUB_BASE_REF")
-    )
+for (pak in golem:::dev_deps) {
+  expect_true(
+    rlang::is_installed(pak)
   )
 }
 
+old <- setwd(temp_app)
 
+usethis::use_build_ignore(".here")
 
 cat(
   readLines("DESCRIPTION"),
   sep = "\n"
 )
 
-
-here::set_here(temp_app)
-
 usethis::use_build_ignore(".here")
 
 usethis::use_dev_package("golem")
@@ -150,19 +127,19 @@ expect_true(
   file.exists("LICENSE")
 )
 expect_true(
-  desc::desc_get("License") == "MIT + file LICENSE"
+  desc_get("License") == "MIT + file LICENSE"
 )
 cat_ok()
 
 cli::cat_rule("Checking the DESCRIPTION is correct")
 expect_true(
-  desc::desc_get("Package") == "golemmetrics"
+  desc_get("Package") == "golemmetrics"
 )
 expect_true(
-  desc::desc_get("Title") == "An Amazing Shiny App"
+  desc_get("Title") == "An Amazing Shiny App"
 )
 expect_true(
-  all(desc::desc_get_deps()$package %in% c("config", "golem", "shiny"))
+  all(desc_get_deps()$package %in% c("config", "golem", "shiny"))
 )
 cat_ok()
 
@@ -209,36 +186,37 @@ golem::fill_desc(
   author_first_name = "Colin", # Your First Name
   author_last_name = "Fay", # Your Last Name
   author_email = "colin@thinkr.fr", # Your Email
-  repo_url = NULL # The URL of the GitHub Repo (optional)
+  repo_url = NULL, # The URL of the GitHub Repo (optional)
+  pkg_version = "0.0.0.9000" # The Version of the package containing the App
 )
 
 cli::cat_rule("checking package name")
 expect_equal(
-  desc::desc_get_field("Package"),
+  desc_get_field("Package"),
   "golemmetrics"
 )
 cat_ok()
 cli::cat_rule("checking pkg_title name")
 expect_equal(
-  desc::desc_get_field("Title"),
+  desc_get_field("Title"),
   "A App with Metrics about 'Golem'"
 )
 cat_ok()
 cli::cat_rule("checking package name")
 expect_equal(
-  desc::desc_get_field("Description"),
+  desc_get_field("Description"),
   "Read metrics about {golem}."
 )
 cat_ok()
 cli::cat_rule("checking package name")
 expect_equal(
-  as.character(desc::desc_get_author()),
+  as.character(desc_get_author()),
   "Colin Fay <colin@thinkr.fr> [cre, aut]"
 )
 cat_ok()
 cli::cat_rule("checking package version")
 expect_equal(
-  as.character(desc::desc_get_version()),
+  as.character(desc_get_version()),
   "0.0.0.9000"
 )
 cat_ok()
@@ -248,7 +226,7 @@ cli::cat_rule("set_golem_options")
 golem::set_golem_options()
 expect_equal(
   golem::get_golem_wd(),
-  here::here()
+  golem::pkg_path()
 )
 expect_equal(
   golem::get_golem_name(),
@@ -269,7 +247,7 @@ cli::cat_rule("Create Common Files")
 # usethis::use_mit_license( "Golem User" )
 
 expect_equal(
-  desc::desc_get_field("License"),
+  desc_get_field("License"),
   "MIT + file LICENSE"
 )
 expect_true(
@@ -280,7 +258,7 @@ expect_true(
   file.exists("README.Rmd")
 )
 
-usethis::use_code_of_conduct()
+usethis::use_code_of_conduct("Golem user")
 expect_true(
   file.exists("CODE_OF_CONDUCT.md")
 )
@@ -299,7 +277,7 @@ expect_true(
   dir.exists("tests")
 )
 
-golem::use_recommended_deps()
+# golem::use_recommended_deps()
 
 golem::use_utils_ui(with_test = TRUE)
 expect_true(
@@ -321,11 +299,11 @@ cli::cat_rule("Going through 02_dev.R")
 
 cli::cat_rule("Testing usepackage")
 if (!requireNamespace("cranlogs")) {
-  install.packages("cranlogs")
+  pak::pak("cranlogs")
 }
 usethis::use_package("cranlogs")
 expect_true(
-  "cranlogs" %in% desc::desc_get_deps()$package
+  "cranlogs" %in% desc_get_deps()$package
 )
 cat_ok()
 
@@ -389,41 +367,39 @@ expect_true(
 )
 unlink("R/utils_helpers.R", TRUE, TRUE)
 
-golem::add_js_file("script", template = crystalmountains::js_file)
-golem::add_js_handler("handlers", template = crystalmountains::js_handler)
-golem::add_css_file("custom", template = crystalmountains::css_file)
+golem::add_js_file("script", template = crystalmountains::js_file, open = FALSE)
+golem::add_js_handler("handlers", template = crystalmountains::js_handler, open = FALSE)
+golem::add_css_file("custom", template = crystalmountains::css_file, open = FALSE)
 
 cli::cat_rule("Testing and installing package")
 golem::document_and_reload()
+
+usethis::use_dev_package(
+  "golem",
+  remotes = "https://github.com/ThinkR-open/golem"
+)
+
 devtools::test()
 cat_ok()
 
 cli::cat_rule("Testing 03_dev")
 devtools::check()
-remotes::install_local(force = TRUE)
+remotes::install_local(force = TRUE, upgrade = FALSE)
 targz <- devtools::build()
-remotes::install_local(targz)
-
-cli::cat_rule("Testing 03_dev")
+remotes::install_local(targz, force = TRUE, upgrade = FALSE)
 
 cat_ok()
 
-if (Sys.info()["sysname"] == "Linux") {
-  golem::add_rstudioconnect_file()
-  golem::add_dockerfile(
-    repos = "https://packagemanager.rstudio.com/all/__linux__/focal/latest",
-    from = "rocker/shiny-verse:4.0.4",
-    extra_sysreqs = c("libxml2-dev"),
-    open = FALSE
-  )
-  usethis::use_git()
-  dir.create(".git/hooks", recursive = TRUE)
-  file.create(".git/hooks/pre-commit")
-  install.packages("rsconnect")
-  rsconnect::writeManifest()
-  install.packages("knitr")
-  knitr::knit("README.Rmd")
-}
+golem::add_rstudioconnect_file()
+
+golem::add_dockerfile_with_renv(
+  repos = "https://packagemanager.rstudio.com/all/__linux__/focal/latest",
+  from = "rocker/shiny-verse:4.0.4",
+  extra_sysreqs = c("libxml2-dev"),
+  open = FALSE,
+  output_dir = "/golemmetrics/deploy",
+  document = FALSE
+)
 
 # Restore old wd
 
