@@ -71,7 +71,6 @@ unlink(file.path(tpdir, fakename), recursive = TRUE)
 create_golem(file.path(tpdir, fakename), open = FALSE)
 pkg <- file.path(tpdir, fakename)
 
-
 fp <- file.path("inst/app", randir)
 dir.create(file.path(pkg, fp), recursive = TRUE)
 
@@ -80,8 +79,32 @@ rand_name <- function() {
 }
 
 withr::with_dir(pkg, {
-  set_golem_options()
+  # Some weird things with {here}
+  unloadNamespace("here")
+  if (!file.exists(".here")) {
+    here::set_here(path_to_golem)
+  }
+  if (requireNamespace("desc", quietly = TRUE)) {
+    set_golem_options()
+  }
   usethis::proj_set(pkg)
-  orig_test <- set_golem_wd(pkg)
+  orig_test <- set_golem_wd(
+    pkg = pkg
+  )
   usethis::use_mit_license("Golem")
 })
+
+
+create_deploy_folder <- function(){
+file.path(
+    tempdir(),
+    make.names(
+      paste0(
+        "deploy",
+        round(
+          runif(1, min = 0, max = 99999)
+        )
+      )
+    )
+  )
+}
