@@ -15,7 +15,12 @@ test_that("add_module", {
     lapply(tools::file_ext(script), function(x) testthat::expect_equal(x, "R"))
     ## Test message of function
     remove_file("R/mod_output.R")
-    output <- testthat::capture_output(add_module("output", open = FALSE))
+    withr::with_options(
+      c("golem.quiet" = FALSE),
+      {
+        output <- testthat::capture_output(add_module("output", open = FALSE))
+      }
+    )
     expect_true(
       stringr::str_detect(output, "File created at R/mod_output.R")
     )
